==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/AccumulationDistributionIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AccumulationDistributionIndicatorStrategy } from "./AccumulationDistributionIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var AccumulationDistributionIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AccumulationDistributionIndicator, _super);
    function AccumulationDistributionIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AccumulationDistributionIndicator.prototype.get_yy = function () {
        return new AccumulationDistributionIndicatorStrategy();
    };
    Object.defineProperty(AccumulationDistributionIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    AccumulationDistributionIndicator.prototype.get_zb = function () {
        return AccumulationDistributionIndicator.$;
    };
    Object.defineProperty(AccumulationDistributionIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    AccumulationDistributionIndicator.$t = markType(AccumulationDistributionIndicator, 'AccumulationDistributionIndicator', StrategyBasedIndicator.$);
    return AccumulationDistributionIndicator;
}(StrategyBasedIndicator));
export { AccumulationDistributionIndicator };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/AccumulationDistributionIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AccumulationDistributionIndicatorStrategy } from "./AccumulationDistributionIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var AccumulationDistributionIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AccumulationDistributionIndicator, _super);
    function AccumulationDistributionIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AccumulationDistributionIndicator.prototype.bj = function () {
        return new AccumulationDistributionIndicator();
    };
    AccumulationDistributionIndicator.prototype.get_abq = function () {
        return new AccumulationDistributionIndicatorStrategy();
    };
    Object.defineProperty(AccumulationDistributionIndicator.prototype, "abq", {
        get: function () {
            return this.get_abq();
        },
        enumerable: false,
        configurable: true
    });
    AccumulationDistributionIndicator.prototype.get_ab3 = function () {
        return AccumulationDistributionIndicator.$;
    };
    Object.defineProperty(AccumulationDistributionIndicator.prototype, "ab3", {
        get: function () {
            return this.get_ab3();
        },
        enumerable: false,
        configurable: true
    });
    AccumulationDistributionIndicator.$t = markType(AccumulationDistributionIndicator, 'AccumulationDistributionIndicator', StrategyBasedIndicator.$);
    return AccumulationDistributionIndicator;
}(StrategyBasedIndicator));
export { AccumulationDistributionIndicator };
